@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2018 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,28 +32,31 @@
  *
  *  @param f The expression you want to display.
  */
-#define DEBUG(f) do { \
-	if (CDebug::Debug()) { \
-		CDebugStream sDebug;\
-		sDebug << f;\
-	} \
-} while (0)
+#define DEBUG(f)                 \
+    do {                         \
+        if (CDebug::Debug()) {   \
+            CDebugStream sDebug; \
+            sDebug << f;         \
+        }                        \
+    } while (0)
 
 class CDebug {
-public:
-	static void SetStdoutIsTTY(bool b) { stdoutIsTTY = b; }
-	static bool StdoutIsTTY() { return stdoutIsTTY; }
-	static void SetDebug(bool b) { debug = b; }
-	static bool Debug() { return debug; }
+  public:
+    static void SetStdoutIsTTY(bool b) { stdoutIsTTY = b; }
+    static bool StdoutIsTTY() { return stdoutIsTTY; }
+    static void SetDebug(bool b) { debug = b; }
+    static bool Debug() { return debug; }
 
-protected:
-	static bool stdoutIsTTY;
-	static bool debug;
+    static CString Filter(const CString& sUnfilteredLine);
+
+  protected:
+    static bool stdoutIsTTY;
+    static bool debug;
 };
 
 class CDebugStream : public std::ostringstream {
-public:
-	~CDebugStream();
+  public:
+    ~CDebugStream();
 };
 
-#endif // !ZNCDEBUG_H
+#endif  // !ZNCDEBUG_H
