@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2015 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2018 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,21 +15,22 @@
  */
 
 #include <znc/Modules.h>
+#include <znc/Client.h>
 
 class CMissingMotd : public CModule {
-public:
-	MODCONSTRUCTOR(CMissingMotd) {}
+  public:
+    MODCONSTRUCTOR(CMissingMotd) {}
 
-	virtual void OnClientLogin() override {
-		PutUser(":irc.znc.in 422 :MOTD File is missing");
-	}
+    void OnClientLogin() override {
+        PutUser(":irc.znc.in 422 " + GetClient()->GetNick() +
+                " :MOTD File is missing");
+    }
 };
 
-template<> void TModInfo<CMissingMotd>(CModInfo& Info)
-{
+template <>
+void TModInfo<CMissingMotd>(CModInfo& Info) {
     Info.SetWikiPage("missingmotd");
     Info.SetHasArgs(false);
 }
 
-USERMODULEDEFS(CMissingMotd, "Sends 422 to clients when they login")
-
+USERMODULEDEFS(CMissingMotd, t_s("Sends 422 to clients when they login"))
