@@ -144,7 +144,7 @@ class CSChat : public CModule {
     EModRet OnUserRawMessage(CMessage& msg) override {
         if (!msg.GetCommand().Equals("schat")) return CONTINUE;
 
-        const CString sParams = msg.GetParams(0);
+        const CString sParams = msg.GetParamsColon(0);
         if (sParams.empty()) {
             PutModule("SChat User Area ...");
             OnModCommand("help");
