@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2015 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2018 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,17 +16,17 @@
 
 #include <znc/Server.h>
 
-CServer::CServer(const CString& sName, unsigned short uPort, const CString& sPass, bool bSSL) {
-	m_sName = sName;
-	m_uPort = (uPort) ? uPort : (unsigned short)6667;
-	m_sPass = sPass;
-	m_bSSL = bSSL;
-}
+CServer::CServer(const CString& sName, unsigned short uPort,
+                 const CString& sPass, bool bSSL)
+    : m_sName(sName),
+      m_uPort((uPort) ? uPort : (unsigned short)6667),
+      m_sPass(sPass),
+      m_bSSL(bSSL) {}
 
 CServer::~CServer() {}
 
 bool CServer::IsValidHostName(const CString& sHostName) {
-	return (!sHostName.empty() && (sHostName.find(' ') == CString::npos));
+    return (!sHostName.empty() && !sHostName.Contains(" "));
 }
 
 const CString& CServer::GetName() const { return m_sName; }
@@ -35,6 +35,7 @@ const CString& CServer::GetPass() const { return m_sPass; }
 bool CServer::IsSSL() const { return m_bSSL; }
 
 CString CServer::GetString(bool bIncludePassword) const {
-	return m_sName + " " + CString(m_bSSL ? "+" : "") + CString(m_uPort) +
-		CString(bIncludePassword ? (m_sPass.empty() ? "" : " " + m_sPass) : "");
+    return m_sName + " " + CString(m_bSSL ? "+" : "") + CString(m_uPort) +
+           CString(bIncludePassword ? (m_sPass.empty() ? "" : " " + m_sPass)
+                                    : "");
 }
